=== modified file 'bzrlib/tests/test_btree_index.py'
--- bzrlib/tests/test_btree_index.py	2009-09-09 19:32:27 +0000
+++ bzrlib/tests/test_btree_index.py	2009-10-09 15:02:19 +0000
@@ -1119,6 +1119,8 @@
 
     def test_supports_unlimited_cache(self):
         builder = btree_index.BTreeBuilder(reference_lists=0, key_elements=1)
+        # We need enough nodes to cause a page split (so we have both an
+        # internal node and a couple leaf nodes. 500 seems to be enough.)
         nodes = self.make_nodes(500, 1, 0)
         for node in nodes:
             builder.add_node(*node)
@@ -1126,6 +1128,11 @@
         trans = get_transport(self.get_url())
         size = trans.put_file('index', stream)
         index = btree_index.BTreeGraphIndex(trans, 'index', size)
+        self.assertEqual(500, index.key_count())
+        # We have an internal node
+        self.assertEqual(2, len(index._row_lengths))
+        # We have at least 2 leaf nodes
+        self.assertTrue(index._row_lengths[-1] >= 2)
         self.assertIsInstance(index._leaf_node_cache, lru_cache.LRUCache)
         self.assertEqual(btree_index._NODE_CACHE_SIZE,
                          index._leaf_node_cache._max_cache)
@@ -1143,7 +1150,9 @@
                                             unlimited_cache=True)
         self.assertIsInstance(index._leaf_node_cache, dict)
         self.assertIs(type(index._internal_node_cache), dict)
-        entries = set(index.iter_entries([nodes[0][1], nodes[300][0]]))
+        # Exercise the lookup code
+        entries = set(index.iter_entries([n[0] for n in nodes]))
+        self.assertEqual(500, len(entries))
 
 
 class TestBTreeNodes(BTreeTestCase):

